@@ -1,10 +1,11 @@
 
-package org.virtualbox_6_0.jaxws;
+package org.virtualbox_6_1.jaxws;
 
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlElement;
 import javax.xml.bind.annotation.XmlRootElement;
+import javax.xml.bind.annotation.XmlSchemaType;
 import javax.xml.bind.annotation.XmlType;
 
 
@@ -39,6 +40,7 @@ public class IAudioAdapterSetAudioController {
     @XmlElement(required = true)
     protected String _this;
     @XmlElement(required = true)
+    @XmlSchemaType(name = "string")
     protected AudioControllerType audioController;
 
     /**
